#filetrail {
	font-size: 1.4em;
	margin-bottom: 30px;
}
#filetrail a {
	font-weight: bold;
}






#fileView {
	padding: 5px;
	margin-right: 180px;
}

#fileStats {
	font-size: 1.2em;
	color: #ccc;
	padding: 0;
}


#imageFile img {
	max-width: 500px;
	border: 1px solid #000;
	margin-top: 30px;
}

pre#embeddableFile {
	margin: 30px 0 0 0;
	font-size: 0.8em;
	padding: 0;
	border: none;
}


#dircontents {
	float: right;
	width: 150px;
}

#dircontents td {
	background-position: 3px center;
	background-repeat: no-repeat;
	padding: 6px 6px 6px 23px;
}
#dircontents td.typeFolder{
	background-image: url('folder_icon.gif')
}
#dircontents td.typeBin{
	background-image: url('file_icon.gif')
}
#dircontents td.typeImage{
	background-image: url('image_icon.gif')
}
#dircontents td.typeEmbeddable{
	background-image: url('document_icon.gif')
}

#dircontents td.selectedFile{
	background-color: #ccc;
	font-weight: bold;
}
